@@ -49,7 +49,7 @@ class ODmeasurement:
             if next_step.lower() == "x":
                 break
             else:
-                self.pe.mix(100)
+                self.pe.mix(self.pe.mixer_speed)
                 time.sleep(5)
                 self.pe.mix(0)
                 time.sleep(3)
